from django.core.management.base import BaseCommand

from rest_mock_server import generator
from rest_mock_server import mock_server


class Command(BaseCommand):
    help = 'Starts mock server (generates file if necessary)'

    def add_arguments(self, parser):
        parser.add_argument(
            '--file',
            dest='server_file',
            help='Express server file path'
        )

    def handle(self, *args, **options):
        server_file = options.get('server_file')

        if not server_file:
            generator.main()
            server_file = 'index.js'

        mock_server.main(server_file)



import os
import shutil
import subprocess
import sys


def main(index_file):
    # Check if node is installed
    try:
        subprocess.check_output(['node', '-v'])
    except:
        sys.stdout.write('Node.js not installed properly.\n')
        sys.exit(0)

    # Check if Express is installed
    try:
        subprocess.check_output(['npm', 'list', 'express'])
    except:
        subprocess.call(['npm', 'install', 'express'])

    try:
        subprocess.call(["node", index_file])
    except KeyboardInterrupt:
        os.remove(index_file)
        shutil.rmtree('node_modules')
        sys.stdout.write('Mock server shutdown.\n')



from django.core.management.base import BaseCommand

from rest_mock_server import generator


class Command(BaseCommand):
    help = 'Generates an Express server file for mocking endpoint responses'

    def add_arguments(self, parser):
        parser.add_argument(
            '--output',
            dest='output_file',
            help='Custom output file name'
        )
        parser.add_argument(
            '--port',
            dest='port',
            help='Custom port to be exposed'
        )

    def handle(self, *args, **options):
        output = options.get('output_file')
        port = options.get('port', 8000)

        generator.main(output=output, port=port)
